@@ -22,13 +22,13 @@ class NSLoader(BaseLoader):
             "x-moon-os-language": "en-US",
             "x-moon-app-language": "en-US",
             "authorization": "",
-            "x-moon-app-internal-version": "305",
-            "x-moon-app-display-version": "1.15.1",
+            "x-moon-app-internal-version": "310",
+            "x-moon-app-display-version": "1.16.0",
             "x-moon-os": "IOS",
             "accept-encoding": "gzip;q=1.0, compress;q=0.5",
             "accept-language": "en-US;q=1.0",
-            "user-agent": "moon_ios/1.15.1 (com.nintendo.znma; build:305; iOS 14.6) "
-            "Alamofire/4.8.2",
+            "user-agent": "moon_ios/1.16.0 (com.nintendo.znma; build:310; iOS 15.1.0) "
+            "Alamofire/1.16.0",
             "x-moon-timezone": "America/Los_Angeles",
         }
         self.s = requests.Session()
